==> openshift-model-5.1.1-sources.jar: annotations/io/fabric8/openshift/api/model/ResourceQuotaStatusByNamespaceFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.ResourceQuotaStatus;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ResourceQuotaStatusByNamespaceFluentImpl<A extends ResourceQuotaStatusByNamespaceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ResourceQuotaStatusByNamespaceFluent<A> {

    private String namespace;
    private ResourceQuotaStatus status;

    public ResourceQuotaStatusByNamespaceFluentImpl() {
    }

    public ResourceQuotaStatusByNamespaceFluentImpl(ResourceQuotaStatusByNamespace instance) {
        this.withNamespace(instance.getNamespace()); 
        this.withStatus(instance.getStatus()); 
    }

    public String getNamespace() {
        return this.namespace;
    }

    public A withNamespace(String namespace) {
        this.namespace=namespace; return (A) this;
    }

    public Boolean hasNamespace() {
        return this.namespace != null;
    }

    public A withNewNamespace(String arg1) {
        return (A)withNamespace(new String(arg1));
    }

    public A withNewNamespace(StringBuilder arg1) {
        return (A)withNamespace(new String(arg1));
    }

    public A withNewNamespace(StringBuffer arg1) {
        return (A)withNamespace(new String(arg1));
    }

    public ResourceQuotaStatus getStatus() {
        return this.status;
    }

    public A withStatus(ResourceQuotaStatus status) {
        this.status=status; return (A) this;
    }

    public Boolean hasStatus() {
        return this.status != null;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ResourceQuotaStatusByNamespaceFluentImpl that = (ResourceQuotaStatusByNamespaceFluentImpl) o;
        if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
        if (status != null ? !status.equals(that.status) :that.status != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(namespace,  status,  super.hashCode());
    }

}

==> openshift-model-5.3.2-sources.jar: annotations/io/fabric8/openshift/api/model/ResourceQuotaStatusByNamespaceFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.ResourceQuotaStatus;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ResourceQuotaStatusByNamespaceFluentImpl<A extends ResourceQuotaStatusByNamespaceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ResourceQuotaStatusByNamespaceFluent<A> {

    private String namespace;
    private ResourceQuotaStatus status;

    public ResourceQuotaStatusByNamespaceFluentImpl() {
    }

    public ResourceQuotaStatusByNamespaceFluentImpl(ResourceQuotaStatusByNamespace instance) {
        this.withNamespace(instance.getNamespace()); 
        this.withStatus(instance.getStatus()); 
    }

    public String getNamespace() {
        return this.namespace;
    }

    public A withNamespace(String namespace) {
        this.namespace=namespace; return (A) this;
    }

    public Boolean hasNamespace() {
        return this.namespace != null;
    }

    public A withNewNamespace(StringBuilder arg1) {
        return (A)withNamespace(new String(arg1));
    }

    public A withNewNamespace(int[] arg1,int arg2,int arg3) {
        return (A)withNamespace(new String(arg1, arg2, arg3));
    }

    public A withNewNamespace(char[] arg1) {
        return (A)withNamespace(new String(arg1));
    }

    public A withNewNamespace(StringBuffer arg1) {
        return (A)withNamespace(new String(arg1));
    }

    public A withNewNamespace(byte[] arg1,int arg2) {
        return (A)withNamespace(new String(arg1, arg2));
    }

    public A withNewNamespace(byte[] arg1) {
        return (A)withNamespace(new String(arg1));
    }

    public A withNewNamespace(char[] arg1,int arg2,int arg3) {
        return (A)withNamespace(new String(arg1, arg2, arg3));
    }

    public A withNewNamespace(byte[] arg1,int arg2,int arg3) {
        return (A)withNamespace(new String(arg1, arg2, arg3));
    }

    public A withNewNamespace(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withNamespace(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewNamespace(String arg1) {
        return (A)withNamespace(new String(arg1));
    }

    public ResourceQuotaStatus getStatus() {
        return this.status;
    }

    public A withStatus(ResourceQuotaStatus status) {
        this.status=status; return (A) this;
    }

    public Boolean hasStatus() {
        return this.status != null;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ResourceQuotaStatusByNamespaceFluentImpl that = (ResourceQuotaStatusByNamespaceFluentImpl) o;
        if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
        if (status != null ? !status.equals(that.status) :that.status != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(namespace,  status,  super.hashCode());
    }

}
